@@ -969,5 +969,125 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     for error in errors:
         if error[1] == True:
             return error[0], False
+    return "OK", True
 
+def modifyFilesNewGroup(version, group,project_name):
+    errors = []
+    # Crear version en project_name/urls.py
+    # Importar public versions de nueva versión
+    publicpath = f"api/v{version}/public_urls.py"
+    privatepath = f"api/v{version}/private_urls.py"
+    find = f"# v{version} PATTERNS (Managed by SPRINGLABS_DJANGO)"
+    uppergroup=group.upper()
+    content = f"""
+# START {uppergroup} URLS v{version} (Managed by SPRINGLABS_DJANGO)
+{group}_patterns = [
+    # {uppergroup} URLS (Managed by SPRINGLABS_DJANGO)
+] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
+# END {uppergroup} URLS v{version} (Managed by SPRINGLABS_DJANGO)
+
+"""
+    message, result = appendContent(path=publicpath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    message, result = appendContent(path=privatepath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    find="# PATTERNS URLS (Managed by SPRINGLABS_DJANGO)"
+    content=f"    url(r'^', include({group}_patterns)),"
+    message, result = appendContent(path=privatepath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    message, result = appendContent(path=publicpath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    find="# Our custom libraries (Managed by SPRINGLABS_DJANGO)"
+    content=f"from .{group}.schema import ExampleDjangoQueries"
+    path=f"graphql_api/v{version}/api.py"
+    message, result = appendContent(path=path,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    for error in errors:
+        if error[1] == True:
+            return error[0], False
+    
+    return "OK", True
+
+def createDirectoriesNewGroup(version, group, project_name):
+    errors = []
+    primary_package = "springlabs_django"
+    os.chdir(f"api/v{version}")
+    os.mkdir(group)
+
+    base_serializers_py = "/core/new_version/api/baseSerializers.py"
+    base_views_py = "/core/new_version/api/baseViews.py"
+    
+    # Obtiene contenido de core/new_version/api/baseSerializers.py
+    try:
+        template_serializers_py = pkgutil.get_data(primary_package, base_serializers_py).decode('utf-8')
+    except:
+        message = f"Ocurrió un error interno en core/new_version/api/baseSerializers.py"
+        errors.append([message, True])
+
+    # Obtiene contenido de core/new_version/api/baseViews.py
+    try:
+        template_views_py = pkgutil.get_data(primary_package, base_views_py).decode('utf-8')
+    except:
+        message = f"Ocurrió un error interno en core/new_version/api/baseViews.py"
+        errors.append([message, True])
+
+    # Escribe contenido base en archivo api/new_version/users/serializers.py
+    with open(f"{group}/serializers.py", "w") as file:
+        file. write(template_serializers_py)
+    
+    # Escribe contenido base en archivo api/new_version/users/views.py
+    with open(f"{group}/views.py", "w") as file:
+        file. write(template_views_py)
+    os.chdir("../..")
+
+    os.chdir(f"graphql_api/v{version}")
+    os.mkdir(group)
+    base_schema_py = "/core/new_version/graphql_api/baseSchema.py"
+    base_types_py = "/core/new_version/graphql_api/baseTypes.py"
+
+    # Obtiene contenido de core/new_version/graphql_api/baseSchema.py
+    try:
+        template_schema_py = pkgutil.get_data(primary_package, base_schema_py).decode('utf-8')
+    except:
+        message = f"Ocurrió un error interno en core/new_version/graphql_api/baseSchema.py"
+        errors.append([message, True])
+
+    # Obtiene contenido de core/new_version/graphql_api/baseTypes.py
+    try:
+        template_types_py = pkgutil.get_data(primary_package, base_types_py).decode('utf-8')
+    except:
+        message = f"Ocurrió un error interno en core/new_version/graphql_api/baseTypes.py"
+        errors.append([message, True])
+
+     # Escribe contenido base en archivo graphql_api/new_version/users/schema.py
+    with open(f"{group}/schema.py", "w") as file:
+        file. write(template_schema_py)
+    
+    # Escribe contenido base en archivo graphql_api/new_version/users/types.py
+    with open(f"{group}/types.py", "w") as file:
+        file. write(template_types_py)
+    os.chdir("../..")
+    for error in errors:
+        if error[1] == True:
+            return error[0], False
     return "OK", True
\ No newline at end of file
