@@ -2,7 +2,7 @@ import click
 import time
 import os
 import re
-from springlabs_django.utils import createVersion, createAPI, createGraph
+from springlabs_django.utils import createVersion, createAPI, createGraph, getVersions, createGroup
 from springlabs_django.validators import *
 from springlabs_django import __version__ as version
 
@@ -11,26 +11,50 @@ from springlabs_django import __version__ as version
 @click.version_option(version=version, prog_name="Springlabs Django Manager", message="%(prog)s, v%(version)s")
 @click.pass_context
 def cli(ctx):
-    """Springlabs Django Manager."""
-    ctx.invoked_subcommand
+	"""Springlabs Django Manager."""
+	ctx.invoked_subcommand
 
 
 @cli.command()
 @click.option('-ve', '--version',
-    prompt='Inserta tu versión',
-    help='Nueva version para la aplicación',
-    callback=validate_version_version)
+	prompt='Inserta tu versión',
+	help='Nueva version para la aplicación',
+	callback=validate_version_version)
 def create_version(version):
-    """ Create a new version for django project """
-    message, result = createVersion(version=version,
-        project_name=project_name,
-        old_versions=versions)
-    if result == True:
-        message = f"Se creó version '{version}' correctamente"
-        click.secho(message, fg='green')
-    else:
-        message = "Error: " + message
-        click.secho(message, fg='red')
+	""" Create a new version for django project """
+	message, result = createVersion(version=version,
+		project_name=project_name,
+		old_versions=versions)
+	if result == True:
+		message = f"Se creó version '{version}' correctamente"
+		click.secho(message, fg='green')
+	else:
+		message = "Error: " + message
+		click.secho(message, fg='red')
+
+@cli.command()
+@click.option('-ve','--version',
+	prompt='Inserta la versión',
+	help='Version a la que se agregara el grupo',
+	type=click.Choice(getVersions(), case_sensitive=False)
+	)
+@click.option('-gr','--group',
+	prompt='Inserta el nombre del grupo' ,
+	help='Nuevo grupo para la aplicación',
+	callback=validate_group_group)
+def create_group(group,version):
+	""" Create a new group for django project """
+	message, result = createGroup(version=version,
+		group=group,
+		project_name=project_name
+		)
+	if result == True:
+		message = f"Se creó el grupo '{group}' correctamente"
+		click.secho(message, fg='green')
+	else:
+		message = "Error: " + message
+		click.secho(message, fg='red')
+
 
 @cli.command()
 @click.option('-ve', '--version',
@@ -121,4 +145,4 @@ def create_graph(version, group, name,type_graph):
         click.secho(message, fg='red')
 
 if __name__ == '__main__':
-    cli()
+	cli()
