@@ -16,7 +16,9 @@ from .primary_functions import (
     modifyFilesNewVersion,
     createDirectoriesNewVersion,
     modifyFilesNewAPI,
-    modifyFilesNewGraph
+    modifyFilesNewGraph,
+    modifyFilesNewGroup,
+    createDirectoriesNewGroup
 )
 
 def createVersion(version, project_name, old_versions):
@@ -253,4 +255,70 @@ def createGraph(version,group,name,type_graph,project_name):
             os.chdir(project_name)
             return error[0], False
     
-    return "OK", True
\ No newline at end of file
+    return "OK", True
+
+def getVersions():
+    try:
+        with open("springlabs_django.json", "r") as file:
+            data = json.load(file)
+        versions = data["versions"]
+    except:
+        versions=["1"]
+    return versions
+
+def createGroup(version, group, project_name):
+
+    # Generar respaldo de proyecto
+    message, result = generateBackup(project_name=project_name)
+    if result == False:
+        message = "Ocurrió un error interno al crear respaldo"
+        return message, False
+    
+    errors=[]
+    message,result=modifyFilesNewGroup(version, group,project_name)
+    if result == False:
+        errors.append([message, True])
+
+    # Crea directorios y archivos dentro para un nuevo grupo
+    message, result = createDirectoriesNewGroup(version, group, project_name)
+    
+    # Si falla al modificar directorios se agrega a arreglo
+    if result == False:
+        errors.append([message, True])
+
+
+    try:
+        with open('springlabs_django.json') as file:
+            data = json.load(file)
+    except Exception as e:
+        message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+        errors.append([message, True])
+    else:
+        objGroupDetail = {
+                    "group": group,
+                    "apis": [],
+                    "graph": [{"graph_name": "ExampleDjango",
+                    "graph_type": "open"}]
+                }
+
+        for obj in data["versions_detail"]:
+            if obj["version"]==version:
+                obj["groups"].append(group)
+                obj["groups_detail"]=[]
+                obj["groups_detail"].append(objGroupDetail)
+        try:
+            with open("springlabs_django.json", "w") as file:
+                file.write(json.dumps(data))
+        except:
+            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+            errors.append([message, True])
+    for error in errors:
+        if error[1] == True:
+            print("errros$$$$$$$$$$")
+            message, result = reverseChanges(project_name=project_name)
+            os.chdir("..")
+            os.remove(project_name + ".zip")
+            os.chdir(project_name)
+            return error[0], False
+    print("creado utls")
+    return "OK", True
