@@ -7,6 +7,7 @@ try:
         data = json.load(file)
     versions = data["versions"]
     project_name = data["project_name"]
+    versions_detail=data["versions_detail"]
 except:
     message = "Command python_django should be executed in root project (springlabs_django.json)"
     raise click.BadParameter(message)
@@ -296,5 +297,18 @@ def validate_graph_name(ctx, param, value):
             message = f"El nombre del graph '{name_graph}' ya se encuentra registrado en la aplicación"
             raise click.BadParameter(message)
         return value
+    return value
 
+def validate_group_group(ctx, param, value):
+    
+    message, result = validate_manage()
+    if result == False:
+        raise click.BadParameter(message)
+    insertversion=ctx.params["version"]
+
+    for detail in versions_detail:
+        if detail["version"]==insertversion:
+            if value.upper() in (gr.upper() for gr in detail["groups"]):
+                message = f"group '{value}' already exists in version '{insertversion}'"
+                raise click.BadParameter(message)
     return value
\ No newline at end of file
